import { SchedulerProConfig, PresetManager } from '@bryntum/schedulerpro';
/**
 * Application config file
 */

const zoomLevels = {
    minuteAndHour : 1,
    hourAndDay    : 1
};

export const schedulerProConfig: Partial<SchedulerProConfig> = {
    // Limit zoom levels to those which use hours to make filtering non-working time works better in this demo
    presets : PresetManager.records.filter(preset => zoomLevels[preset.id]),

    // A Project holds the data and the calculation engine for Scheduler Pro. It also acts as a CrudManager, allowing
    // loading data into all stores at once
    project : {
        autoLoad  : true,
        transport : {
            load : {
                url : './assets/data/data.json'
            }
        }
    },
    startDate         : '2020-03-23',
    endDate           : '2020-03-28',
    rowHeight         : 90,
    barMargin         : 15,
    eventStyle        : 'border',
    resourceImagePath : './assets/users/',

    // Custom viewPreset (based on 'hourAndDay') that displays a compact 24 hour bottom header
    viewPreset : {
        base              : 'hourAndDay',
        tickWidth         : 30,
        displayDateFormat : 'll HH:mm',
        headers           : [
            {
                unit       : 'day',
                dateFormat : 'ddd DD/MM' //Mon 01/10
            },
            {
                unit       : 'hour',
                dateFormat : 'HH'
            }
        ]
    },

    // Not using the dependencies feature
    features : {
        dependencies : false
    },

    columns : [
    // Column that displays a thumb for the resource
        {
            type : 'resourceInfo',
            text : 'Manager'
        }
    ],

    tbar : [
    // Add a button to filter out non-working time
        {
            ref         : 'filterButton',
            type        : 'button',
            text        : 'Filter out non-working time',
            toggleable  : true,
            icon        : 'b-fa-square',
            pressedIcon : 'b-fa-check-square'
        }
    ]
};
