import { AssignmentModel, CalendarModel, DependencyModel, EventModel, ResourceModel } from "@bryntum/schedulerpro";

export enum MacchinaTipo {
    Interna = 0,
    Esterna = 1
}

export enum FaseStato {
    Pronta = 0,
    InLavorazione = 1,
    Conclusa = 2,
    Sospesa = 3
}



export class FaseSchedulazione {
    Id: number;
    CucituraData: FaseSchedulazioneCucitura;
    OdPId: number;
    OdPCodice: string;
    CommessaCodice: string;
    CommessaDescrizione: string;
    MacchinaId: number;
    MacchinaTipo?: MacchinaTipo;
    Numero: number;
    Stato: FaseStato;
    StatoString: string;
    IsPrimaFase: boolean;
    IsUltimaFase: boolean;
    Descrizione: string;
    StartDate: Date;
    EndDate: Date;
    OdPDueDate?: Date;
    MaterialeCodice: string;
    MaterialeDescrizione: string;
    QtaPrevista: number;
    QtaProdotta: number;
    QtaScarto: number;
    MaterialeUdM: string;
    TempoCiclo: number;
    TempoAttrezzaggio: number;
    IsLocked: boolean;
    IsNew: boolean;
}

export class FaseSchedulazioneCucitura {
    CucituraId: number;
    Fasi: FaseSchedulazioneCucita[];
}

export class FaseSchedulazioneCucita {
    Id: number;
    OdPId: number;
    OdPCodice: string;
    Descrizione: string;
}

export class SchedulazioneData {
    Events: SchedulazioneEventModel[];
    Resources: SchedulazioneResourceModel[];
    Assignments: AssignmentModel[];
    Dependencies: DependencyModel[];
    Calendars: CalendarModel[];
    MinDate: Date;
    MaxDate: Date;
    SchedulingWindowCalendarId: string;
    NonWorkingEventsData: NonWorkingEventsData;
}

export class SchedulazioneEventModel extends EventModel {
    // proprietà già presenti in EventModel
    id: number|string;
    startDate: Date;
    endDate: Date;
    name: string; // conterrà la descrizione
    eventColor: string; // conterrà colore random
    manuallyScheduled: boolean; // avrà sempre valore TRUE

    // proprietà aggiunte:
    eventType: SchedulazioneEventType;
    eventStatus: SchedulazioneEventStatus;
    // per tenere traccia dell'highlighting
    highlighted: boolean; 
    // le fasi lockate sono quelle relative a fasi in stato diverso da pronto
    // o che, essendo nuove fasi schedulate, risultino parzialmente fuori dall'intervallo di schedulazione
    isLocked: boolean;
    // per tenere traccia delle fasi che stanno venendo schedulate ex novo sulla finestra di pianificazione
    isNew: boolean; 
    originalEventColor: string // per tenere traccia del colore random iniziale;

    isOnResourceWithInfiniteCapacity: boolean; // indica se si tratta di una fase su una risorsa a capacità infinita

    // tutti dati di fase che potrebbero servire
    faseData: FaseSchedulazione;
}

export enum SchedulazioneEventType {
    Normale = 0
}

export enum SchedulazioneEventStatus {
    Valid = 0,
    InvalidDuration = 1,
    InvalidPositionWithRespectToPrecedences = 2,
    InvalidPositionWithRespectToNonWorkingTimes = 3,
    OutsideSchedulingWindow = 4
}

// scopo di questa classe è velocizzare l'accesso
// ai dati degli intervalli non lavorativi, in ordine
// ascendente o discendente in base alle necessità
export class NonWorkingEventsData {
    Ascending: Record<number, SchedulazioneEventModel[]>;
    Descending: Record<number, SchedulazioneEventModel[]>;
}

export class SchedulazioneResourceModel extends ResourceModel {
    // proprietà già presenti in ResourceModel
    id: number;
    name: string;   
    iconCls: string;
    calendar: string;

    // proprietà aggiunte:
    classeMacchina: string;
    ordinamento: number;
    color: string;
    isInfiteCapacity: boolean;
}
